cemento.cli package — CEMENTO 0.9.6 documentation

Skip to main content
`Ctrl`+`K`

# cemento.cli package

## Submodules

## cemento.cli.constants module

cemento.cli.constants.get_version()

## cemento.cli.download module

cemento.cli.download.download_default_reference_ontos(data_path: Path) → list[str]

cemento.cli.download.make_data_dirs(download_path: str | Path) → Path

cemento.cli.download.register(subparsers)

cemento.cli.download.run(args)

## cemento.cli.drawio_ttl module

cemento.cli.drawio_ttl.register(subparsers)

cemento.cli.drawio_ttl.run(args)

## cemento.cli.ttl_drawio module

cemento.cli.ttl_drawio.register(subparsers)

cemento.cli.ttl_drawio.run(args)

## Module contents